## v0.1.15 (2025-04-10)

### Other Changes

- cff2e96 Remove unused icon mapping for gpt-3.5-turbo and format list comprehensions for better readability (Vinh Nguyen)
- 420bb59 Refactor README and routing logic: streamline content, remove unused routes, and enhance message handling in conversation handlers (Vinh Nguyen)
- cf02386 Update CHANGELOG.md to include recent enhancements in release automation and changelog generation (Vinh Nguyen)
- afdd172 Enhance release automation: add changelog generation and GitHub release creation; refactor version update process (Vinh Nguyen)

## v0.1.14 (2025-04-10)

### Other Changes

- afdd172 Enhance release automation: add changelog generation and GitHub release creation; refactor version update process (Vinh Nguyen)

## v0.1.14 (2025-04-10)

### Other Changes

- d4c84ad Refactor chat profile starters to shuffle on app startup; add random prompt generation functions for enhanced user experience (Vinh Nguyen)
- ae61d6c Enhance routing capabilities and add specialized prompts for conversation types; update README for clarity on supported routes and training instructions (Vinh Nguyen)
- 12c050f Fix typos in image generation starter message for clarity (Vinh Nguyen)
- e92b4ad Add development mode instructions to README; update LLM provider configuration and default settings (Vinh Nguyen)
- b112e56 Update README for application run instructions and upgrade methods; modify pyproject.toml target version to Python 3.12 (Vinh Nguyen)
- bc4ebaf Refactor LLM provider settings: rename module and update imports across conversation handlers, media processors, and settings builder (Vinh Nguyen)
- a61deac Refactor README for clarity on installation methods and voice interaction; update LLM model aliases in provider settings (Vinh Nguyen)
- b089d52 Update README to clarify voice interaction features and remove outdated interface controls (Vinh Nguyen)
- 87038f4 Update README from llm docs inspiration (Vinh Nguyen)
- 1bdd2ad Update README.md to include quick start instructions with uvx and upgrade methods (Vinh Nguyen)

## v0.1.14 (2025-04-10)

### Other Changes

- d4c84ad Refactor chat profile starters to shuffle on app startup; add random prompt generation functions for enhanced user experience (Vinh Nguyen)
- ae61d6c Enhance routing capabilities and add specialized prompts for conversation types; update README for clarity on supported routes and training instructions (Vinh Nguyen)
- 12c050f Fix typos in image generation starter message for clarity (Vinh Nguyen)
- e92b4ad Add development mode instructions to README; update LLM provider configuration and default settings (Vinh Nguyen)
- b112e56 Update README for application run instructions and upgrade methods; modify pyproject.toml target version to Python 3.12 (Vinh Nguyen)
- bc4ebaf Refactor LLM provider settings: rename module and update imports across conversation handlers, media processors, and settings builder (Vinh Nguyen)
- a61deac Refactor README for clarity on installation methods and voice interaction; update LLM model aliases in provider settings (Vinh Nguyen)
- b089d52 Update README to clarify voice interaction features and remove outdated interface controls (Vinh Nguyen)
- 87038f4 Update README from llm docs inspiration (Vinh Nguyen)
- 1bdd2ad Update README.md to include quick start instructions with uvx and upgrade methods (Vinh Nguyen)

# Changelog

## v0.1.14 (2025-04-10)

### Other Changes

- d4c84ad Refactor chat profile starters to shuffle on app startup; add random prompt generation functions for enhanced user experience (Vinh Nguyen)
- ae61d6c Enhance routing capabilities and add specialized prompts for conversation types; update README for clarity on supported routes and training instructions (Vinh Nguyen)
- 12c050f Fix typos in image generation starter message for clarity (Vinh Nguyen)
- e92b4ad Add development mode instructions to README; update LLM provider configuration and default settings (Vinh Nguyen)
- b112e56 Update README for application run instructions and upgrade methods; modify pyproject.toml target version to Python 3.12 (Vinh Nguyen)
- bc4ebaf Refactor LLM provider settings: rename module and update imports across conversation handlers, media processors, and settings builder (Vinh Nguyen)
- a61deac Refactor README for clarity on installation methods and voice interaction; update LLM model aliases in provider settings (Vinh Nguyen)
- b089d52 Update README to clarify voice interaction features and remove outdated interface controls (Vinh Nguyen)
- 87038f4 Update README from llm docs inspiration (Vinh Nguyen)
- 1bdd2ad Update README.md to include quick start instructions with uvx and upgrade methods (Vinh Nguyen)

